summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
commit458efa7b0c935cbaafa2791021a5f8f7241aa876 (patch)
tree624583f2873febe23770bee3fa94b5c24bd59f4f /src/gui/editors/matrix
parent747037b72944ae2c02962b7c5c96e0a7f8852e38 (diff)
downloadrosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.tar.gz
rosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.zip
Initial TQt4 port of Rosegarden
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1230242 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/editors/matrix')
-rw-r--r--src/gui/editors/matrix/MatrixCanvasView.cpp12
-rw-r--r--src/gui/editors/matrix/MatrixCanvasView.h11
-rw-r--r--src/gui/editors/matrix/MatrixElement.cpp4
-rw-r--r--src/gui/editors/matrix/MatrixEraser.cpp6
-rw-r--r--src/gui/editors/matrix/MatrixHLayout.cpp4
-rw-r--r--src/gui/editors/matrix/MatrixHLayout.h16
-rw-r--r--src/gui/editors/matrix/MatrixMover.cpp26
-rw-r--r--src/gui/editors/matrix/MatrixMover.h1
-rw-r--r--src/gui/editors/matrix/MatrixPainter.cpp18
-rw-r--r--src/gui/editors/matrix/MatrixPainter.h1
-rw-r--r--src/gui/editors/matrix/MatrixParameterBox.cpp4
-rw-r--r--src/gui/editors/matrix/MatrixParameterBox.h5
-rw-r--r--src/gui/editors/matrix/MatrixResizer.cpp20
-rw-r--r--src/gui/editors/matrix/MatrixResizer.h1
-rw-r--r--src/gui/editors/matrix/MatrixSelector.cpp30
-rw-r--r--src/gui/editors/matrix/MatrixSelector.h3
-rw-r--r--src/gui/editors/matrix/MatrixStaff.cpp4
-rw-r--r--src/gui/editors/matrix/MatrixTool.cpp16
-rw-r--r--src/gui/editors/matrix/MatrixTool.h1
-rw-r--r--src/gui/editors/matrix/MatrixToolBox.cpp8
-rw-r--r--src/gui/editors/matrix/MatrixToolBox.h3
-rw-r--r--src/gui/editors/matrix/MatrixVLayout.h10
-rw-r--r--src/gui/editors/matrix/MatrixView.cpp390
-rw-r--r--src/gui/editors/matrix/MatrixView.h22
-rw-r--r--src/gui/editors/matrix/PianoKeyboard.cpp22
-rw-r--r--src/gui/editors/matrix/PianoKeyboard.h7
-rw-r--r--src/gui/editors/matrix/QCanvasMatrixDiamond.cpp4
-rw-r--r--src/gui/editors/matrix/QCanvasMatrixDiamond.h6
-rw-r--r--src/gui/editors/matrix/QCanvasMatrixRectangle.h6
29 files changed, 336 insertions, 325 deletions
diff --git a/src/gui/editors/matrix/MatrixCanvasView.cpp b/src/gui/editors/matrix/MatrixCanvasView.cpp
index f97ceaf..5782164 100644
--- a/src/gui/editors/matrix/MatrixCanvasView.cpp
+++ b/src/gui/editors/matrix/MatrixCanvasView.cpp
@@ -45,9 +45,9 @@ namespace Rosegarden
MatrixCanvasView::MatrixCanvasView(MatrixStaff& staff,
SnapGrid *snapGrid,
bool drumMode,
- TQCanvas *viewing, TQWidget *parent,
+ TQCanvas *viewing, TQWidget *tqparent,
const char *name, WFlags f)
- : RosegardenCanvasView(viewing, parent, name, f),
+ : RosegardenCanvasView(viewing, tqparent, name, f),
m_staff(staff),
m_snapGrid(snapGrid),
m_drumMode(drumMode),
@@ -55,7 +55,7 @@ MatrixCanvasView::MatrixCanvasView(MatrixStaff& staff,
m_previousEvPitch(0),
m_mouseWasPressed(false),
m_ignoreClick(false),
- m_smoothModifier(Qt::ShiftButton),
+ m_smoothModifier(TQt::ShiftButton),
m_lastSnap(SnapGrid::SnapToBeat),
m_isSnapTemporary(false)
{
@@ -130,7 +130,7 @@ void MatrixCanvasView::contentsMousePressEvent(TQMouseEvent* e)
// TQCanvas::collisions() can be a bit optimistic and report
// items which are close to the point but not actually under it.
// So a little sanity check helps.
- if (!rect.contains(p, true)) continue;
+ if (!rect.tqcontains(p, true)) continue;
mel = &(mRect->getMatrixElement());
// std::cerr << "MatrixCanvasView::contentsMousePressEvent: collision with an existing matrix element" << std::endl;
@@ -198,7 +198,7 @@ void MatrixCanvasView::contentsMouseMoveEvent(TQMouseEvent* e)
QCanvasMatrixRectangle *mRect = 0;
if ((mRect = dynamic_cast<QCanvasMatrixRectangle*>(item))) {
- if (!mRect->rect().contains(p, true))
+ if (!mRect->rect().tqcontains(p, true))
continue;
mel = &(mRect->getMatrixElement());
MATRIX_DEBUG << "have element" << endl;
@@ -268,7 +268,7 @@ void MatrixCanvasView::slotExternalWheelEvent(TQWheelEvent* e)
void MatrixCanvasView::updateGridSnap(TQMouseEvent *e)
{
- Qt::ButtonState bs = e->state();
+ TQt::ButtonState bs = e->state();
// MATRIX_DEBUG << "MatrixCanvasView::updateGridSnap : bs = "
// << bs << " - sm = " << getSmoothModifier() << ", is temporary " << m_isSnapTemporary << ", saved is " << m_lastSnap << endl;
diff --git a/src/gui/editors/matrix/MatrixCanvasView.h b/src/gui/editors/matrix/MatrixCanvasView.h
index 694856e..5391f9f 100644
--- a/src/gui/editors/matrix/MatrixCanvasView.h
+++ b/src/gui/editors/matrix/MatrixCanvasView.h
@@ -48,25 +48,26 @@ class MatrixElement;
class MatrixCanvasView : public RosegardenCanvasView
{
Q_OBJECT
+ TQ_OBJECT
public:
MatrixCanvasView(MatrixStaff&,
SnapGrid *,
bool drumMode,
TQCanvas *viewing,
- TQWidget *parent=0, const char *name=0, WFlags f=0);
+ TQWidget *tqparent=0, const char *name=0, WFlags f=0);
~MatrixCanvasView();
- void setSmoothModifier(Qt::ButtonState s) { m_smoothModifier = s; }
- Qt::ButtonState getSmoothModifier() { return m_smoothModifier; }
+ void setSmoothModifier(TQt::ButtonState s) { m_smoothModifier = s; }
+ TQt::ButtonState getSmoothModifier() { return m_smoothModifier; }
signals:
/**
* Emitted when the user clicks on a TQCanvasItem which is active
*
- * @see QCanvasItem#setActive
+ * @see TQCanvasItem#setActive
*/
void activeItemPressed(TQMouseEvent*,
TQCanvasItem* item);
@@ -150,7 +151,7 @@ protected:
bool m_mouseWasPressed;
bool m_ignoreClick;
- Qt::ButtonState m_smoothModifier;
+ TQt::ButtonState m_smoothModifier;
timeT m_lastSnap;
bool m_isSnapTemporary;
};
diff --git a/src/gui/editors/matrix/MatrixElement.cpp b/src/gui/editors/matrix/MatrixElement.cpp
index c706c87..b60b63f 100644
--- a/src/gui/editors/matrix/MatrixElement.cpp
+++ b/src/gui/editors/matrix/MatrixElement.cpp
@@ -87,7 +87,7 @@ void MatrixElement::drawOverlapRectangles()
if (m_overlapRectangles) removeOverlapRectangles();
TQRect elRect = m_canvasRect->rect();
- QCanvasItemList
+ TQCanvasItemList
itemList = m_canvasRect->canvas()->collisions(elRect);
TQCanvasItemList::Iterator it;
MatrixElement* mel = 0;
@@ -120,7 +120,7 @@ void MatrixElement::drawOverlapRectangles()
void MatrixElement::redrawOverlaps(TQRect rect)
{
- QCanvasItemList
+ TQCanvasItemList
itemList = m_canvasRect->canvas()->collisions(rect);
TQCanvasItemList::Iterator it;
MatrixElement* mel = 0;
diff --git a/src/gui/editors/matrix/MatrixEraser.cpp b/src/gui/editors/matrix/MatrixEraser.cpp
index 226c4a8..a5f261a 100644
--- a/src/gui/editors/matrix/MatrixEraser.cpp
+++ b/src/gui/editors/matrix/MatrixEraser.cpp
@@ -43,8 +43,8 @@
namespace Rosegarden
{
-MatrixEraser::MatrixEraser(MatrixView* parent)
- : MatrixTool("MatrixEraser", parent),
+MatrixEraser::MatrixEraser(MatrixView* tqparent)
+ : MatrixTool("MatrixEraser", tqparent),
m_currentStaff(0)
{
TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
@@ -96,7 +96,7 @@ void MatrixEraser::handleLeftButtonPress(timeT,
void MatrixEraser::ready()
{
- m_mParentView->setCanvasCursor(Qt::pointingHandCursor);
+ m_mParentView->setCanvasCursor(TQt::pointingHandCursor);
setBasicContextHelp();
}
diff --git a/src/gui/editors/matrix/MatrixHLayout.cpp b/src/gui/editors/matrix/MatrixHLayout.cpp
index 99b89c2..f4615fa 100644
--- a/src/gui/editors/matrix/MatrixHLayout.cpp
+++ b/src/gui/editors/matrix/MatrixHLayout.cpp
@@ -61,7 +61,7 @@ void MatrixHLayout::scanStaff(Staff &staffBase,
{
Profiler profiler("MatrixHLayout::scanStaff", true);
- // The Matrix layout is not currently designed to be able to lay
+ // The Matrix tqlayout is not currently designed to be able to lay
// out more than one staff, because we have no requirement to show
// more than one at once in the Matrix view. To make it work for
// multiple staffs should be straightforward; we just need to bear
@@ -88,7 +88,7 @@ void MatrixHLayout::scanStaff(Staff &staffBase,
}
// Do this in two parts: bar lines separately from elements.
- // (We don't need to do all that stuff notationhlayout has to do,
+ // (We don't need to do all that stuff notationhtqlayout has to do,
// scanning the notes bar-by-bar; we can just place the bar lines
// in the theoretically-correct places and do the same with the
// notes quite independently.)
diff --git a/src/gui/editors/matrix/MatrixMover.cpp b/src/gui/editors/matrix/MatrixMover.cpp
index adf558d..0b84537 100644
--- a/src/gui/editors/matrix/MatrixMover.cpp
+++ b/src/gui/editors/matrix/MatrixMover.cpp
@@ -54,8 +54,8 @@
namespace Rosegarden
{
-MatrixMover::MatrixMover(MatrixView* parent) :
- MatrixTool("MatrixMover", parent),
+MatrixMover::MatrixMover(MatrixView* tqparent) :
+ MatrixTool("MatrixMover", tqparent),
m_currentElement(0),
m_currentStaff(0),
m_lastPlayedPitch(-1)
@@ -101,7 +101,7 @@ void MatrixMover::handleLeftButtonPress(timeT time,
MATRIX_DEBUG << "MatrixMover::handleLeftButtonPress() : time = " << time << ", el = " << el << endl;
if (!el) return;
- m_quickCopy = (e->state() & Qt::ControlButton);
+ m_quickCopy = (e->state() & TQt::ControlButton);
if (!m_duplicateElements.empty()) {
for (size_t i = 0; i < m_duplicateElements.size(); ++i) {
@@ -123,16 +123,16 @@ void MatrixMover::handleLeftButtonPress(timeT time,
if (selection) {
EventSelection *newSelection;
- if ((e->state() & Qt::ShiftButton) ||
- selection->contains(m_currentElement->event()))
+ if ((e->state() & TQt::ShiftButton) ||
+ selection->tqcontains(m_currentElement->event()))
newSelection = new EventSelection(*selection);
else
newSelection = new EventSelection(m_currentStaff->getSegment());
// if the selection already contains the event, remove it from the
// selection if shift is pressed
- if (selection->contains(m_currentElement->event())){
- if (e->state() & Qt::ShiftButton)
+ if (selection->tqcontains(m_currentElement->event())){
+ if (e->state() & TQt::ShiftButton)
newSelection->removeEvent(m_currentElement->event());
} else {
newSelection->addEvent(m_currentElement->event());
@@ -207,7 +207,7 @@ int MatrixMover::handleMouseMove(timeT newTime,
<< newTime << endl;
if (e) {
- setBasicContextHelp(e->state() & Qt::ControlButton);
+ setBasicContextHelp(e->state() & TQt::ControlButton);
}
if (!m_currentElement || !m_currentStaff)
@@ -420,17 +420,17 @@ void MatrixMover::handleMouseRelease(timeT newTime,
void MatrixMover::ready()
{
- connect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ connect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
connect(this, TQT_SIGNAL(hoveredOverNoteChanged(int, bool, timeT)),
m_mParentView, TQT_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
- m_mParentView->setCanvasCursor(Qt::sizeAllCursor);
+ m_mParentView->setCanvasCursor(TQt::sizeAllCursor);
setBasicContextHelp();
}
void MatrixMover::stow()
{
- disconnect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ disconnect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
disconnect(this, TQT_SIGNAL(hoveredOverNoteChanged(int, bool, timeT)),
m_mParentView, TQT_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
@@ -441,8 +441,8 @@ void MatrixMover::slotMatrixScrolled(int newX, int newY)
if (!m_currentElement)
return ;
- TQPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
- m_parentView->getCanvasView()->contentsY());
+ TQPoint newP1(newX, newY), oldP1(m_tqparentView->getCanvasView()->contentsX(),
+ m_tqparentView->getCanvasView()->contentsY());
TQPoint offset = newP1 - oldP1;
diff --git a/src/gui/editors/matrix/MatrixMover.h b/src/gui/editors/matrix/MatrixMover.h
index 258b465..9886bdd 100644
--- a/src/gui/editors/matrix/MatrixMover.h
+++ b/src/gui/editors/matrix/MatrixMover.h
@@ -47,6 +47,7 @@ class Event;
class MatrixMover : public MatrixTool
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixToolBox;
diff --git a/src/gui/editors/matrix/MatrixPainter.cpp b/src/gui/editors/matrix/MatrixPainter.cpp
index 11bbc0b..7616de6 100644
--- a/src/gui/editors/matrix/MatrixPainter.cpp
+++ b/src/gui/editors/matrix/MatrixPainter.cpp
@@ -53,8 +53,8 @@
namespace Rosegarden
{
-MatrixPainter::MatrixPainter(MatrixView* parent)
- : MatrixTool("MatrixPainter", parent),
+MatrixPainter::MatrixPainter(MatrixView* tqparent)
+ : MatrixTool("MatrixPainter", tqparent),
m_currentElement(0),
m_currentStaff(0)
{
@@ -83,8 +83,8 @@ MatrixPainter::MatrixPainter(MatrixView* parent)
createMenu("matrixpainter.rc");
}
-MatrixPainter::MatrixPainter(TQString name, MatrixView* parent)
- : MatrixTool(name, parent),
+MatrixPainter::MatrixPainter(TQString name, MatrixView* tqparent)
+ : MatrixTool(name, tqparent),
m_currentElement(0),
m_currentStaff(0)
{}
@@ -320,17 +320,17 @@ void MatrixPainter::handleMouseRelease(timeT endTime,
void MatrixPainter::ready()
{
- connect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ connect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
- m_mParentView->setCanvasCursor(Qt::crossCursor);
+ m_mParentView->setCanvasCursor(TQt::crossCursor);
setBasicContextHelp();
}
void MatrixPainter::stow()
{
- disconnect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ disconnect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
}
@@ -339,8 +339,8 @@ void MatrixPainter::slotMatrixScrolled(int newX, int newY)
if (!m_currentElement)
return ;
- TQPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
- m_parentView->getCanvasView()->contentsY());
+ TQPoint newP1(newX, newY), oldP1(m_tqparentView->getCanvasView()->contentsX(),
+ m_tqparentView->getCanvasView()->contentsY());
TQPoint offset = newP1 - oldP1;
diff --git a/src/gui/editors/matrix/MatrixPainter.h b/src/gui/editors/matrix/MatrixPainter.h
index e04cda9..f7e8e6f 100644
--- a/src/gui/editors/matrix/MatrixPainter.h
+++ b/src/gui/editors/matrix/MatrixPainter.h
@@ -47,6 +47,7 @@ class Event;
class MatrixPainter : public MatrixTool
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixToolBox;
diff --git a/src/gui/editors/matrix/MatrixParameterBox.cpp b/src/gui/editors/matrix/MatrixParameterBox.cpp
index 75228c3..cd4a743 100644
--- a/src/gui/editors/matrix/MatrixParameterBox.cpp
+++ b/src/gui/editors/matrix/MatrixParameterBox.cpp
@@ -42,8 +42,8 @@ namespace Rosegarden
{
MatrixParameterBox::MatrixParameterBox(RosegardenGUIDoc *doc,
- TQWidget *parent, const char* name):
- TQFrame(parent, name),
+ TQWidget *tqparent, const char* name):
+ TQFrame(tqparent, name),
m_quantizations(BasicQuantizer::getStandardQuantizations()),
m_doc(doc)
{
diff --git a/src/gui/editors/matrix/MatrixParameterBox.h b/src/gui/editors/matrix/MatrixParameterBox.h
index 036571b..d67269a 100644
--- a/src/gui/editors/matrix/MatrixParameterBox.h
+++ b/src/gui/editors/matrix/MatrixParameterBox.h
@@ -44,12 +44,13 @@ class Instrument;
class EventSelection;
-class MatrixParameterBox : public QFrame
+class MatrixParameterBox : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
- MatrixParameterBox(RosegardenGUIDoc *doc=0, TQWidget *parent=0, const char* name=0);
+ MatrixParameterBox(RosegardenGUIDoc *doc=0, TQWidget *tqparent=0, const char* name=0);
~MatrixParameterBox();
void initBox();
diff --git a/src/gui/editors/matrix/MatrixResizer.cpp b/src/gui/editors/matrix/MatrixResizer.cpp
index fce4306..fc3af58 100644
--- a/src/gui/editors/matrix/MatrixResizer.cpp
+++ b/src/gui/editors/matrix/MatrixResizer.cpp
@@ -51,8 +51,8 @@
namespace Rosegarden
{
-MatrixResizer::MatrixResizer(MatrixView* parent)
- : MatrixTool("MatrixResizer", parent),
+MatrixResizer::MatrixResizer(MatrixView* tqparent)
+ : MatrixTool("MatrixResizer", tqparent),
m_currentElement(0),
m_currentStaff(0)
{
@@ -110,8 +110,8 @@ void MatrixResizer::handleLeftButtonPress(timeT,
if (selection) {
EventSelection *newSelection;
- if ((e->state() & Qt::ShiftButton) ||
- selection->contains(m_currentElement->event()))
+ if ((e->state() & TQt::ShiftButton) ||
+ selection->tqcontains(m_currentElement->event()))
newSelection = new EventSelection(*selection);
else
newSelection = new EventSelection(m_currentStaff->getSegment());
@@ -289,27 +289,27 @@ void MatrixResizer::handleMouseRelease(timeT newTime,
void MatrixResizer::ready()
{
- connect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ connect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
- m_mParentView->setCanvasCursor(Qt::sizeHorCursor);
+ m_mParentView->setCanvasCursor(TQt::sizeHorCursor);
setBasicContextHelp();
}
void MatrixResizer::stow()
{
- disconnect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ disconnect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
}
void MatrixResizer::slotMatrixScrolled(int newX, int newY)
{
- TQPoint newP1(newX, newY), oldP1(m_parentView->getCanvasView()->contentsX(),
- m_parentView->getCanvasView()->contentsY());
+ TQPoint newP1(newX, newY), oldP1(m_tqparentView->getCanvasView()->contentsX(),
+ m_tqparentView->getCanvasView()->contentsY());
TQPoint p(newX, newY);
if (newP1.x() > oldP1.x()) {
- p.setX(newX + m_parentView->getCanvasView()->visibleWidth());
+ p.setX(newX + m_tqparentView->getCanvasView()->visibleWidth());
}
p = m_mParentView->inverseMapPoint(p);
diff --git a/src/gui/editors/matrix/MatrixResizer.h b/src/gui/editors/matrix/MatrixResizer.h
index f851fba..cbbf8cc 100644
--- a/src/gui/editors/matrix/MatrixResizer.h
+++ b/src/gui/editors/matrix/MatrixResizer.h
@@ -47,6 +47,7 @@ class Event;
class MatrixResizer : public MatrixTool
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixToolBox;
diff --git a/src/gui/editors/matrix/MatrixSelector.cpp b/src/gui/editors/matrix/MatrixSelector.cpp
index ef553a5..3109aec 100644
--- a/src/gui/editors/matrix/MatrixSelector.cpp
+++ b/src/gui/editors/matrix/MatrixSelector.cpp
@@ -71,7 +71,7 @@ MatrixSelector::MatrixSelector(MatrixView* view)
m_matrixView(view),
m_selectionToMerge(0)
{
- connect(m_parentView, TQT_SIGNAL(usedSelection()),
+ connect(m_tqparentView, TQT_SIGNAL(usedSelection()),
this, TQT_SLOT(slotHideSelection()));
new KAction(i18n("Switch to Draw Tool"), "pencil", 0, this,
@@ -133,7 +133,7 @@ void MatrixSelector::handleLeftButtonPress(timeT time,
//
delete m_selectionToMerge; // you can safely delete 0, you know?
const EventSelection *selectionToMerge = 0;
- if (e->state() & Qt::ShiftButton)
+ if (e->state() & TQt::ShiftButton)
selectionToMerge = m_mParentView->getCurrentSelection();
m_selectionToMerge =
@@ -153,10 +153,10 @@ void MatrixSelector::handleLeftButtonPress(timeT time,
resizeStart = x + width - 10;
if (p.x() > resizeStart) {
- m_dispatchTool = m_parentView->
+ m_dispatchTool = m_tqparentView->
getToolBox()->getTool(MatrixResizer::ToolName);
} else {
- m_dispatchTool = m_parentView->
+ m_dispatchTool = m_tqparentView->
getToolBox()->getTool(MatrixMover::ToolName);
}
@@ -169,7 +169,7 @@ void MatrixSelector::handleLeftButtonPress(timeT time,
element);
return ;
- } else if (e->state() & Qt::ControlButton) {
+ } else if (e->state() & TQt::ControlButton) {
handleMidButtonPress(time, height, staffNo, e, element);
return;
@@ -214,7 +214,7 @@ void MatrixSelector::handleLeftButtonPress(timeT time,
}
}
- //m_parentView->setCursorPosition(p.x());
+ //m_tqparentView->setCursorPosition(p.x());
}
void MatrixSelector::handleMidButtonPress(timeT time,
@@ -229,7 +229,7 @@ void MatrixSelector::handleMidButtonPress(timeT time,
if (dynamic_cast<MatrixElement*>(element))
return ;
- m_dispatchTool = m_parentView->
+ m_dispatchTool = m_tqparentView->
getToolBox()->getTool(MatrixPainter::ToolName);
m_dispatchTool->ready();
@@ -375,7 +375,7 @@ int MatrixSelector::handleMouseMove(timeT time, int height,
int w = int(p.x() - m_selectionRect->x());
int h = int(p.y() - m_selectionRect->y());
- // Qt rectangle dimensions appear to be 1-based
+ // TQt rectangle dimensions appear to be 1-based
if (w > 0)
++w;
else
@@ -443,11 +443,11 @@ void MatrixSelector::ready()
m_selectionRect->hide();
m_selectionRect->setPen(TQPen(GUIPalette::getColour(GUIPalette::SelectionRectangle), 2));
- m_mParentView->setCanvasCursor(Qt::arrowCursor);
+ m_mParentView->setCanvasCursor(TQt::arrowCursor);
//m_mParentView->setPositionTracking(false);
}
- connect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ connect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
setContextHelp(i18n("Click and drag to select; middle-click and drag to draw new note"));
@@ -461,7 +461,7 @@ void MatrixSelector::stow()
m_mParentView->canvas()->update();
}
- disconnect(m_parentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
+ disconnect(m_tqparentView->getCanvasView(), TQT_SIGNAL(contentsMoving (int, int)),
this, TQT_SLOT(slotMatrixScrolled(int, int)));
}
@@ -478,13 +478,13 @@ void MatrixSelector::slotHideSelection()
void MatrixSelector::slotMatrixScrolled(int newX, int newY)
{
if (m_updateRect) {
- int offsetX = newX - m_parentView->getCanvasView()->contentsX();
- int offsetY = newY - m_parentView->getCanvasView()->contentsY();
+ int offsetX = newX - m_tqparentView->getCanvasView()->contentsX();
+ int offsetY = newY - m_tqparentView->getCanvasView()->contentsY();
int w = int(m_selectionRect->width() + offsetX);
int h = int(m_selectionRect->height() + offsetY);
- // Qt rectangle dimensions appear to be 1-based
+ // TQt rectangle dimensions appear to be 1-based
if (w > 0)
++w;
else
@@ -576,7 +576,7 @@ void MatrixSelector::setContextHelpFor(TQPoint p, bool ctrlPressed)
}
if ((mRect = dynamic_cast<QCanvasMatrixRectangle*>(item))) {
- if (! mRect->rect().contains(p, true)) continue;
+ if (! mRect->rect().tqcontains(p, true)) continue;
mel = &(mRect->getMatrixElement());
break;
}
diff --git a/src/gui/editors/matrix/MatrixSelector.h b/src/gui/editors/matrix/MatrixSelector.h
index caa9e4f..1e8a741 100644
--- a/src/gui/editors/matrix/MatrixSelector.h
+++ b/src/gui/editors/matrix/MatrixSelector.h
@@ -50,6 +50,7 @@ class EditTool;
class MatrixSelector : public MatrixTool
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixToolBox;
@@ -97,7 +98,7 @@ public:
/**
* Create the selection rect
*
- * We need this because MatrixView deletes all QCanvasItems
+ * We need this because MatrixView deletes all TQCanvasItems
* along with it. This happens before the MatrixSelector is
* deleted, so we can't delete the selection rect in
* ~MatrixSelector because that leads to double deletion.
diff --git a/src/gui/editors/matrix/MatrixStaff.cpp b/src/gui/editors/matrix/MatrixStaff.cpp
index 55491d0..847c6f9 100644
--- a/src/gui/editors/matrix/MatrixStaff.cpp
+++ b/src/gui/editors/matrix/MatrixStaff.cpp
@@ -166,10 +166,10 @@ void MatrixStaff::positionElement(ViewElement* vel)
//
EventSelection *selection = m_view->getCurrentSelection();
- if (selection && selection->contains(el->event()))
+ if (selection && selection->tqcontains(el->event()))
el->setColour(GUIPalette::getColour(GUIPalette::SelectedElement));
else if (el->event()->has(BaseProperties::TRIGGER_SEGMENT_ID))
- el->setColour(Qt::gray);
+ el->setColour(TQt::gray);
else
el->setColour(DefaultVelocityColour::getInstance()->getColour(velocity));
diff --git a/src/gui/editors/matrix/MatrixTool.cpp b/src/gui/editors/matrix/MatrixTool.cpp
index a478aa3..a0bb68f 100644
--- a/src/gui/editors/matrix/MatrixTool.cpp
+++ b/src/gui/editors/matrix/MatrixTool.cpp
@@ -34,39 +34,39 @@
namespace Rosegarden
{
-MatrixTool::MatrixTool(const TQString& menuName, MatrixView* parent)
- : EditTool(menuName, parent),
- m_mParentView(parent)
+MatrixTool::MatrixTool(const TQString& menuName, MatrixView* tqparent)
+ : EditTool(menuName, tqparent),
+ m_mParentView(tqparent)
{}
void
MatrixTool::slotSelectSelected()
{
- m_parentView->actionCollection()->action("select")->activate();
+ m_tqparentView->actionCollection()->action("select")->activate();
}
void
MatrixTool::slotMoveSelected()
{
- m_parentView->actionCollection()->action("move")->activate();
+ m_tqparentView->actionCollection()->action("move")->activate();
}
void
MatrixTool::slotEraseSelected()
{
- m_parentView->actionCollection()->action("erase")->activate();
+ m_tqparentView->actionCollection()->action("erase")->activate();
}
void
MatrixTool::slotResizeSelected()
{
- m_parentView->actionCollection()->action("resize")->activate();
+ m_tqparentView->actionCollection()->action("resize")->activate();
}
void
MatrixTool::slotDrawSelected()
{
- m_parentView->actionCollection()->action("draw")->activate();
+ m_tqparentView->actionCollection()->action("draw")->activate();
}
const SnapGrid &
diff --git a/src/gui/editors/matrix/MatrixTool.h b/src/gui/editors/matrix/MatrixTool.h
index 9972176..fb45920 100644
--- a/src/gui/editors/matrix/MatrixTool.h
+++ b/src/gui/editors/matrix/MatrixTool.h
@@ -44,6 +44,7 @@ class SnapGrid;
class MatrixTool : public EditTool
{
Q_OBJECT
+ TQ_OBJECT
public:
// virtual void ready();
diff --git a/src/gui/editors/matrix/MatrixToolBox.cpp b/src/gui/editors/matrix/MatrixToolBox.cpp
index dab9632..e38abf1 100644
--- a/src/gui/editors/matrix/MatrixToolBox.cpp
+++ b/src/gui/editors/matrix/MatrixToolBox.cpp
@@ -40,9 +40,9 @@
namespace Rosegarden
{
-MatrixToolBox::MatrixToolBox(MatrixView* parent)
- : EditToolBox(parent),
- m_mParentView(parent)
+MatrixToolBox::MatrixToolBox(MatrixView* tqparent)
+ : EditToolBox(tqparent),
+ m_mParentView(tqparent)
{}
EditTool* MatrixToolBox::createTool(const TQString& toolName)
@@ -73,7 +73,7 @@ EditTool* MatrixToolBox::createTool(const TQString& toolName)
else {
KMessageBox::error(0, TQString("MatrixToolBox::createTool : unrecognised toolname %1 (%2)")
- .arg(toolName).arg(toolNamelc));
+ .tqarg(toolName).tqarg(toolNamelc));
return 0;
}
diff --git a/src/gui/editors/matrix/MatrixToolBox.h b/src/gui/editors/matrix/MatrixToolBox.h
index 4f28c57..b997405 100644
--- a/src/gui/editors/matrix/MatrixToolBox.h
+++ b/src/gui/editors/matrix/MatrixToolBox.h
@@ -42,8 +42,9 @@ class MatrixStaff;
class MatrixToolBox : public EditToolBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- MatrixToolBox(MatrixView* parent);
+ MatrixToolBox(MatrixView* tqparent);
protected:
diff --git a/src/gui/editors/matrix/MatrixVLayout.h b/src/gui/editors/matrix/MatrixVLayout.h
index a33e0d1..538e598 100644
--- a/src/gui/editors/matrix/MatrixVLayout.h
+++ b/src/gui/editors/matrix/MatrixVLayout.h
@@ -58,9 +58,9 @@ public:
timeT = 0);
/**
- * Precomputes layout data for a single staff, updating any
+ * Precomputes tqlayout data for a single staff, updating any
* internal data stores associated with that staff and updating
- * any layout-related properties in the events on the staff's
+ * any tqlayout-related properties in the events on the staff's
* segment.
*/
virtual void scanStaff(Staff &staff,
@@ -68,10 +68,10 @@ public:
timeT = 0);
/**
- * Computes any layout data that may depend on the results of
+ * Computes any tqlayout data that may depend on the results of
* scanning more than one staff. This may mean doing most of
- * the layout (likely for horizontal layout) or nothing at all
- * (likely for vertical layout).
+ * the tqlayout (likely for horizontal tqlayout) or nothing at all
+ * (likely for vertical tqlayout).
*/
virtual void finishLayout(timeT = 0,
timeT = 0);
diff --git a/src/gui/editors/matrix/MatrixView.cpp b/src/gui/editors/matrix/MatrixView.cpp
index 66c1b0d..424b98e 100644
--- a/src/gui/editors/matrix/MatrixView.cpp
+++ b/src/gui/editors/matrix/MatrixView.cpp
@@ -137,13 +137,13 @@ static double xorigin = 0.0;
MatrixView::MatrixView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- TQWidget *parent,
+ TQWidget *tqparent,
bool drumMode)
- : EditView(doc, segments, 3, parent, "matrixview"),
- m_hlayout(&doc->getComposition()),
- m_referenceRuler(new ZoomableMatrixHLayoutRulerScale(m_hlayout)),
- m_vlayout(),
- m_snapGrid(new SnapGrid(&m_hlayout)),
+ : EditView(doc, segments, 3, tqparent, "matrixview"),
+ m_htqlayout(&doc->getComposition()),
+ m_referenceRuler(new ZoomableMatrixHLayoutRulerScale(m_htqlayout)),
+ m_vtqlayout(),
+ m_snapGrid(new SnapGrid(&m_htqlayout)),
m_lastEndMarkerTime(0),
m_hoveredOverAbsoluteTime(0),
m_hoveredOverNoteName(0),
@@ -176,13 +176,13 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
20); // relation target/this (in percent)
connect(m_dockLeft, TQT_SIGNAL(iMBeingClosed()),
- this, TQT_SLOT(slotParametersClosed()));
+ TQT_TQOBJECT(this), TQT_SLOT(slotParametersClosed()));
connect(m_dockLeft, TQT_SIGNAL(hasUndocked()),
- this, TQT_SLOT(slotParametersClosed()));
- // Apparently, hasUndocked() is emitted when the dock widget's
+ TQT_TQOBJECT(this), TQT_SLOT(slotParametersClosed()));
+ // Aptqparently, hasUndocked() is emitted when the dock widget's
// 'close' button on the dock handle is clicked.
connect(m_mainDockWidget, TQT_SIGNAL(docking(KDockWidget*, KDockWidget::DockPosition)),
- this, TQT_SLOT(slotParametersDockedBack(KDockWidget*, KDockWidget::DockPosition)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotParametersDockedBack(KDockWidget*, KDockWidget::DockPosition)));
Composition &comp = doc->getComposition();
@@ -191,9 +191,9 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
initStatusBar();
connect(m_toolBox, TQT_SIGNAL(showContextHelp(const TQString &)),
- this, TQT_SLOT(slotToolHelpChanged(const TQString &)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotToolHelpChanged(const TQString &)));
- TQCanvas *tCanvas = new TQCanvas(this);
+ TQCanvas *tCanvas = new TQCanvas(TQT_TQOBJECT(this));
m_config->setGroup(MatrixViewConfigGroup);
if (m_config->readBoolEntry("backgroundtextures-1.6-plus", true)) {
@@ -205,7 +205,7 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
TQString backgroundPixmap = isDrumMode() ? "bg-paper-white.xpm" : "bg-matrix-lines.xpm";
if (background.load(TQString("%1/misc/%2").
arg(pixmapDir, backgroundPixmap))) {
- tCanvas->setBackgroundPixmap(background);
+ tCanvas->tqsetBackgroundPixmap(background);
}
}
@@ -301,7 +301,7 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
TQT_SIGNAL(showPluginGUI(InstrumentId, int)),
app,
TQT_SLOT(slotShowPluginGUI(InstrumentId, int)));
- connect(parent, // RosegardenGUIView
+ connect(tqparent, // RosegardenGUIView
TQT_SIGNAL(checkTrackAssignments()),
this,
TQT_SLOT(slotCheckTrackAssignments()));
@@ -353,13 +353,13 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
// Connect vertical scrollbars between matrix and piano
//
connect(m_canvasView->verticalScrollBar(), TQT_SIGNAL(valueChanged(int)),
- this, TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
connect(m_canvasView->verticalScrollBar(), TQT_SIGNAL(sliderMoved(int)),
- this, TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotVerticalScrollPianoKeyboard(int)));
- connect(m_canvasView, TQT_SIGNAL(zoomIn()), this, TQT_SLOT(slotZoomIn()));
- connect(m_canvasView, TQT_SIGNAL(zoomOut()), this, TQT_SLOT(slotZoomOut()));
+ connect(m_canvasView, TQT_SIGNAL(zoomIn()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomIn()));
+ connect(m_canvasView, TQT_SIGNAL(zoomOut()), TQT_TQOBJECT(this), TQT_SLOT(slotZoomOut()));
connect(m_pianoView, TQT_SIGNAL(gotWheelEvent(TQWheelEvent*)),
m_canvasView, TQT_SLOT(slotExternalWheelEvent(TQWheelEvent*)));
@@ -368,13 +368,13 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
// the canvas view rulers
//
connect(m_canvasView, TQT_SIGNAL(bottomWidgetHeightChanged(int)),
- this, TQT_SLOT(slotCanvasBottomWidgetHeightChanged(int)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotCanvasBottomWidgetHeightChanged(int)));
connect(m_canvasView, TQT_SIGNAL(mouseEntered()),
- this, TQT_SLOT(slotMouseEnteredCanvasView()));
+ TQT_TQOBJECT(this), TQT_SLOT(slotMouseEnteredCanvasView()));
connect(m_canvasView, TQT_SIGNAL(mouseLeft()),
- this, TQT_SLOT(slotMouseLeftCanvasView()));
+ TQT_TQOBJECT(this), TQT_SLOT(slotMouseLeftCanvasView()));
/*
TQObject::connect
@@ -404,55 +404,55 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
TQObject::connect
(getCanvasView(), TQT_SIGNAL(hoveredOverNoteChanged(int, bool, timeT)),
- this, TQT_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotHoveredOverNoteChanged(int, bool, timeT)));
TQObject::connect
(m_pitchRuler, TQT_SIGNAL(hoveredOverKeyChanged(unsigned int)),
- this, TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
TQObject::connect
(m_pitchRuler, TQT_SIGNAL(keyPressed(unsigned int, bool)),
- this, TQT_SLOT (slotKeyPressed(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeyPressed(unsigned int, bool)));
TQObject::connect
(m_pitchRuler, TQT_SIGNAL(keySelected(unsigned int, bool)),
- this, TQT_SLOT (slotKeySelected(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeySelected(unsigned int, bool)));
TQObject::connect
(m_pitchRuler, TQT_SIGNAL(keyReleased(unsigned int, bool)),
- this, TQT_SLOT (slotKeyReleased(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeyReleased(unsigned int, bool)));
TQObject::connect
(getCanvasView(), TQT_SIGNAL(hoveredOverAbsoluteTimeChanged(unsigned int)),
- this, TQT_SLOT (slotHoveredOverAbsoluteTimeChanged(unsigned int)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverAbsoluteTimeChanged(unsigned int)));
TQObject::connect
(doc, TQT_SIGNAL(pointerPositionChanged(timeT)),
- this, TQT_SLOT(slotSetPointerPosition(timeT)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotSetPointerPosition(timeT)));
- MATRIX_DEBUG << "MatrixView : applying layout\n";
+ MATRIX_DEBUG << "MatrixView : applying tqlayout\n";
- bool layoutApplied = applyLayout();
- if (!layoutApplied)
- KMessageBox::sorry(0, i18n("Couldn't apply piano roll layout"));
+ bool tqlayoutApplied = applyLayout();
+ if (!tqlayoutApplied)
+ KMessageBox::sorry(0, i18n("Couldn't apply piano roll tqlayout"));
else {
MATRIX_DEBUG << "MatrixView : rendering elements\n";
for (unsigned int i = 0; i < m_staffs.size(); ++i) {
m_staffs[i]->positionAllElements();
- m_staffs[i]->getSegment().getRefreshStatus
+ m_staffs[i]->getSegment().getRefreshtqStatus
(m_segmentsRefreshStatusIds[i]).setNeedsRefresh(false);
}
}
StandardRuler *topStandardRuler = new StandardRuler(getDocument(),
- &m_hlayout, int(xorigin), 25,
+ &m_htqlayout, int(xorigin), 25,
false, getCentralWidget());
topStandardRuler->setSnapGrid(m_snapGrid);
setTopStandardRuler(topStandardRuler);
StandardRuler *bottomStandardRuler = new StandardRuler(getDocument(),
- &m_hlayout, 0, 25,
+ &m_htqlayout, 0, 25,
true, getBottomWidget());
bottomStandardRuler->setSnapGrid(m_snapGrid);
setBottomStandardRuler(bottomStandardRuler);
@@ -470,12 +470,12 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
TQObject::connect
(topStandardRuler->getLoopRuler(),
TQT_SIGNAL(setPointerPosition(timeT)),
- this, TQT_SLOT(slotSetInsertCursorPosition(timeT)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotSetInsertCursorPosition(timeT)));
TQObject::connect
(topStandardRuler,
TQT_SIGNAL(dragPointerToPosition(timeT)),
- this, TQT_SLOT(slotSetInsertCursorPosition(timeT)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotSetInsertCursorPosition(timeT)));
topStandardRuler->getLoopRuler()->setBackgroundColor
(GUIPalette::getColour(GUIPalette::InsertCursorRuler));
@@ -490,7 +490,7 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
connect(bottomStandardRuler->getLoopRuler(), TQT_SIGNAL(stopMouseMove()),
m_canvasView, TQT_SLOT(stopAutoScroll()));
connect(m_bottomStandardRuler, TQT_SIGNAL(dragPointerToPosition(timeT)),
- this, TQT_SLOT(slotSetPointerPosition(timeT)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotSetPointerPosition(timeT)));
// Force height for the moment
//
@@ -571,7 +571,7 @@ MatrixView::~MatrixView()
// ~TQCanvasView so we can't do anything about it). This calls
// TQCanvasView::updateContentsSize(), which in turn updates the
// view's scrollbars, hence calling TQScrollBar::setValue(), and
- // sending the QSCrollbar::valueChanged() signal. But we have a
+ // sending the TQSCrollbar::valueChanged() signal. But we have a
// slot connected to that signal
// (MatrixView::slotVerticalScrollPianoKeyboard), which scrolls
// the pianoView. However at this stage the pianoView has already
@@ -639,219 +639,219 @@ void MatrixView::setupActions()
TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/select.xpm"));
toolAction = new KRadioAction(i18n("&Select and Edit"), icon, Key_F2,
- this, TQT_SLOT(slotSelectSelected()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotSelectSelected()),
actionCollection(), "select");
toolAction->setExclusiveGroup("tools");
toolAction = new KRadioAction(i18n("&Draw"), "pencil", Key_F3,
- this, TQT_SLOT(slotPaintSelected()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotPaintSelected()),
actionCollection(), "draw");
toolAction->setExclusiveGroup("tools");
toolAction = new KRadioAction(i18n("&Erase"), "eraser", Key_F4,
- this, TQT_SLOT(slotEraseSelected()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotEraseSelected()),
actionCollection(), "erase");
toolAction->setExclusiveGroup("tools");
toolAction = new KRadioAction(i18n("&Move"), "move", Key_F5,
- this, TQT_SLOT(slotMoveSelected()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotMoveSelected()),
actionCollection(), "move");
toolAction->setExclusiveGroup("tools");
TQCanvasPixmap pixmap(pixmapDir + "/toolbar/resize.xpm");
icon = TQIconSet(pixmap);
toolAction = new KRadioAction(i18n("Resi&ze"), icon, Key_F6,
- this, TQT_SLOT(slotResizeSelected()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotResizeSelected()),
actionCollection(), "resize");
toolAction->setExclusiveGroup("tools");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap("chord")));
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap("chord")));
(new KToggleAction(i18n("C&hord Insert Mode"), icon, Key_H,
- this, TQT_SLOT(slotUpdateInsertModeStatus()),
+ TQT_TQOBJECT(this), TQT_SLOT(slotUpdateInsertModetqStatus()),
actionCollection(), "chord_mode"))->
setChecked(false);
pixmap.load(pixmapDir + "/toolbar/step_by_step.xpm");
icon = TQIconSet(pixmap);
- new KToggleAction(i18n("Ste&p Recording"), icon, 0, this,
+ new KToggleAction(i18n("Ste&p Recording"), icon, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleStepByStep()), actionCollection(),
"toggle_step_by_step");
pixmap.load(pixmapDir + "/toolbar/quantize.png");
icon = TQIconSet(pixmap);
- new KAction(EventQuantizeCommand::getGlobalName(), icon, Key_Equal, this,
+ new KAction(EventQuantizeCommand::getGlobalName(), icon, Key_Equal, TQT_TQOBJECT(this),
TQT_SLOT(slotTransformsQuantize()), actionCollection(),
"quantize");
- new KAction(i18n("Repeat Last Quantize"), Key_Plus, this,
+ new KAction(i18n("Repeat Last Quantize"), Key_Plus, TQT_TQOBJECT(this),
TQT_SLOT(slotTransformsRepeatQuantize()), actionCollection(),
"repeat_quantize");
- new KAction(CollapseNotesCommand::getGlobalName(), Key_Equal + CTRL, this,
+ new KAction(CollapseNotesCommand::getGlobalName(), Key_Equal + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotTransformsCollapseNotes()), actionCollection(),
"collapse_notes");
- new KAction(i18n("&Legato"), Key_Minus, this,
+ new KAction(i18n("&Legato"), Key_Minus, TQT_TQOBJECT(this),
TQT_SLOT(slotTransformsLegato()), actionCollection(),
"legatoize");
new KAction(ChangeVelocityCommand::getGlobalName(10), 0,
- Key_Up + SHIFT, this,
+ Key_Up + SHIFT, TQT_TQOBJECT(this),
TQT_SLOT(slotVelocityUp()), actionCollection(),
"velocity_up");
new KAction(ChangeVelocityCommand::getGlobalName( -10), 0,
- Key_Down + SHIFT, this,
+ Key_Down + SHIFT, TQT_TQOBJECT(this),
TQT_SLOT(slotVelocityDown()), actionCollection(),
"velocity_down");
- new KAction(i18n("Set to Current Velocity"), 0, this,
+ new KAction(i18n("Set to Current Velocity"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetVelocitiesToCurrent()), actionCollection(),
"set_to_current_velocity");
- new KAction(i18n("Set Event &Velocities..."), 0, this,
+ new KAction(i18n("Set Event &Velocities..."), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetVelocities()), actionCollection(),
"set_velocities");
- new KAction(i18n("Trigger Se&gment..."), 0, this,
+ new KAction(i18n("Trigger Se&gment..."), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotTriggerSegment()), actionCollection(),
"trigger_segment");
- new KAction(i18n("Remove Triggers..."), 0, this,
+ new KAction(i18n("Remove Triggers..."), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotRemoveTriggers()), actionCollection(),
"remove_trigger");
- new KAction(i18n("Select &All"), Key_A + CTRL, this,
+ new KAction(i18n("Select &All"), Key_A + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotSelectAll()), actionCollection(),
"select_all");
- new KAction(i18n("&Delete"), Key_Delete, this,
+ new KAction(i18n("&Delete"), Key_Delete, TQT_TQOBJECT(this),
TQT_SLOT(slotEditDelete()), actionCollection(),
"delete");
- new KAction(i18n("Cursor &Back"), 0, Key_Left, this,
+ new KAction(i18n("Cursor &Back"), 0, Key_Left, TQT_TQOBJECT(this),
TQT_SLOT(slotStepBackward()), actionCollection(),
"cursor_back");
- new KAction(i18n("Cursor &Forward"), 0, Key_Right, this,
+ new KAction(i18n("Cursor &Forward"), 0, Key_Right, TQT_TQOBJECT(this),
TQT_SLOT(slotStepForward()), actionCollection(),
"cursor_forward");
- new KAction(i18n("Cursor Ba&ck Bar"), 0, Key_Left + CTRL, this,
+ new KAction(i18n("Cursor Ba&ck Bar"), 0, Key_Left + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotJumpBackward()), actionCollection(),
"cursor_back_bar");
- new KAction(i18n("Cursor For&ward Bar"), 0, Key_Right + CTRL, this,
+ new KAction(i18n("Cursor For&ward Bar"), 0, Key_Right + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotJumpForward()), actionCollection(),
"cursor_forward_bar");
- new KAction(i18n("Cursor Back and Se&lect"), SHIFT + Key_Left, this,
+ new KAction(i18n("Cursor Back and Se&lect"), SHIFT + Key_Left, TQT_TQOBJECT(this),
TQT_SLOT(slotExtendSelectionBackward()), actionCollection(),
"extend_selection_backward");
- new KAction(i18n("Cursor Forward and &Select"), SHIFT + Key_Right, this,
+ new KAction(i18n("Cursor Forward and &Select"), SHIFT + Key_Right, TQT_TQOBJECT(this),
TQT_SLOT(slotExtendSelectionForward()), actionCollection(),
"extend_selection_forward");
- new KAction(i18n("Cursor Back Bar and Select"), SHIFT + CTRL + Key_Left, this,
+ new KAction(i18n("Cursor Back Bar and Select"), SHIFT + CTRL + Key_Left, TQT_TQOBJECT(this),
TQT_SLOT(slotExtendSelectionBackwardBar()), actionCollection(),
"extend_selection_backward_bar");
- new KAction(i18n("Cursor Forward Bar and Select"), SHIFT + CTRL + Key_Right, this,
+ new KAction(i18n("Cursor Forward Bar and Select"), SHIFT + CTRL + Key_Right, TQT_TQOBJECT(this),
TQT_SLOT(slotExtendSelectionForwardBar()), actionCollection(),
"extend_selection_forward_bar");
new KAction(i18n("Cursor to St&art"), 0,
/* #1025717: conflicting meanings for ctrl+a - dupe with Select All
- Key_A + CTRL, */ this,
+ Key_A + CTRL, */ TQT_TQOBJECT(this),
TQT_SLOT(slotJumpToStart()), actionCollection(),
"cursor_start");
- new KAction(i18n("Cursor to &End"), 0, Key_E + CTRL, this,
+ new KAction(i18n("Cursor to &End"), 0, Key_E + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotJumpToEnd()), actionCollection(),
"cursor_end");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-cursor-to-pointer")));
- new KAction(i18n("Cursor to &Playback Pointer"), icon, 0, this,
+ new KAction(i18n("Cursor to &Playback Pointer"), icon, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotJumpCursorToPlayback()), actionCollection(),
"cursor_to_playback_pointer");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-play")));
- KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, this,
+ KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
TQT_SIGNAL(play()), actionCollection(), "play");
// Alternative shortcut for Play
KShortcut playShortcut = play->shortcut();
playShortcut.append( KKey(Key_Return + CTRL) );
play->setShortcut(playShortcut);
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-stop")));
- new KAction(i18n("&Stop"), icon, Key_Insert, this,
+ new KAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
TQT_SIGNAL(stop()), actionCollection(), "stop");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind")));
- new KAction(i18n("Re&wind"), icon, Key_End, this,
+ new KAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlayback()), actionCollection(),
"playback_pointer_back_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd")));
- new KAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+ new KAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
"playback_pointer_forward_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind-end")));
- new KAction(i18n("Rewind to &Beginning"), icon, 0, this,
+ new KAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
"playback_pointer_start");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd-end")));
- new KAction(i18n("Fast Forward to &End"), icon, 0, this,
+ new KAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
"playback_pointer_end");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-pointer-to-cursor")));
- new KAction(i18n("Playback Pointer to &Cursor"), icon, 0, this,
+ new KAction(i18n("Playback Pointer to &Cursor"), icon, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotJumpPlaybackToCursor()), actionCollection(),
"playback_pointer_to_cursor");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-solo")));
- new KToggleAction(i18n("&Solo"), icon, 0, this,
+ new KToggleAction(i18n("&Solo"), icon, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleSolo()), actionCollection(),
"toggle_solo");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-tracking")));
- (new KToggleAction(i18n("Scro&ll to Follow Playback"), icon, Key_Pause, this,
+ (new KToggleAction(i18n("Scro&ll to Follow Playback"), icon, Key_Pause, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleTracking()), actionCollection(),
"toggle_tracking"))->setChecked(m_playTracking);
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-panic")));
- new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+ new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
TQT_SIGNAL(panic()), actionCollection(), "panic");
- new KAction(i18n("Set Loop to Selection"), Key_Semicolon + CTRL, this,
+ new KAction(i18n("Set Loop to Selection"), Key_Semicolon + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotPreviewSelection()), actionCollection(),
"preview_selection");
- new KAction(i18n("Clear L&oop"), Key_Colon + CTRL, this,
+ new KAction(i18n("Clear L&oop"), Key_Colon + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotClearLoop()), actionCollection(),
"clear_loop");
- new KAction(i18n("Clear Selection"), Key_Escape, this,
+ new KAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
TQT_SLOT(slotClearSelection()), actionCollection(),
"clear_selection");
// icon = TQIconSet(TQCanvasPixmap(pixmapDir + "/toolbar/eventfilter.xpm"));
- new KAction(i18n("&Filter Selection"), "filter", Key_F + CTRL, this,
+ new KAction(i18n("&Filter Selection"), "filter", Key_F + CTRL, TQT_TQOBJECT(this),
TQT_SLOT(slotFilterSelection()), actionCollection(),
"filter_selection");
@@ -876,23 +876,23 @@ void MatrixView::setupActions()
timeT d = m_snapValues[i];
if (d == SnapGrid::NoSnap) {
- new KAction(i18n("&No Snap"), 0, this,
+ new KAction(i18n("&No Snap"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSnapFromAction()),
actionCollection(), "snap_none");
} else if (d == SnapGrid::SnapToUnit) {
} else if (d == SnapGrid::SnapToBeat) {
- new KAction(i18n("Snap to Bea&t"), Key_1, this,
+ new KAction(i18n("Snap to Bea&t"), Key_1, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSnapFromAction()),
actionCollection(), "snap_beat");
} else if (d == SnapGrid::SnapToBar) {
- new KAction(i18n("Snap to &Bar"), Key_5, this,
+ new KAction(i18n("Snap to &Bar"), Key_5, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSnapFromAction()),
actionCollection(), "snap_bar");
} else {
timeT err = 0;
TQString label = NotationStrings::makeNoteMenuLabel(d, true, err);
- TQPixmap pixmap = NotePixmapFactory::toQPixmap
+ TQPixmap pixmap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeNoteMenuPixmap(d, err));
KShortcut cut = 0;
@@ -903,9 +903,9 @@ void MatrixView::setupActions()
else if (d == crotchetDuration) cut = Key_4;
else if (d == crotchetDuration * 2) cut = Key_2;
- TQString actionName = TQString("snap_%1").arg(int((crotchetDuration * 4) / d));
+ TQString actionName = TQString("snap_%1").tqarg(int((crotchetDuration * 4) / d));
if (d == (crotchetDuration * 3) / 2) actionName = "snap_3";
- new KAction(i18n("Snap to %1").arg(label), pixmap, cut, this,
+ new KAction(i18n("Snap to %1").tqarg(label), pixmap, cut, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSnapFromAction()), actionCollection(),
actionName);
}
@@ -914,16 +914,16 @@ void MatrixView::setupActions()
//
// Settings menu
//
- new KAction(i18n("Show Instrument Parameters"), 0, this,
+ new KAction(i18n("Show Instrument Parameters"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotDockParametersBack()),
actionCollection(),
"show_inst_parameters");
- new KToggleAction(i18n("Show Ch&ord Name Ruler"), 0, this,
+ new KToggleAction(i18n("Show Ch&ord Name Ruler"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleChordsRuler()),
actionCollection(), "show_chords_ruler");
- new KToggleAction(i18n("Show &Tempo Ruler"), 0, this,
+ new KToggleAction(i18n("Show &Tempo Ruler"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleTempoRuler()),
actionCollection(), "show_tempo_ruler");
@@ -1032,20 +1032,20 @@ bool MatrixView::applyLayout(int staffNo,
{
Profiler profiler("MatrixView::applyLayout", true);
- m_hlayout.reset();
- m_vlayout.reset();
+ m_htqlayout.reset();
+ m_vtqlayout.reset();
for (unsigned int i = 0; i < m_staffs.size(); ++i) {
if (staffNo >= 0 && (int)i != staffNo)
continue;
- m_hlayout.scanStaff(*m_staffs[i], startTime, endTime);
- m_vlayout.scanStaff(*m_staffs[i], startTime, endTime);
+ m_htqlayout.scanStaff(*m_staffs[i], startTime, endTime);
+ m_vtqlayout.scanStaff(*m_staffs[i], startTime, endTime);
}
- m_hlayout.finishLayout();
- m_vlayout.finishLayout();
+ m_htqlayout.finishLayout();
+ m_vtqlayout.finishLayout();
if (m_staffs[0]->getSegment().getEndMarkerTime() != m_lastEndMarkerTime ||
m_lastEndMarkerTime == 0 ||
@@ -1078,7 +1078,7 @@ void MatrixView::refreshSegment(Segment *segment,
}
m_staffs[0]->positionElements(startTime, endTime);
- repaintRulers();
+ tqrepaintRulers();
}
TQSize MatrixView::getViewSize()
@@ -1096,10 +1096,10 @@ void MatrixView::setViewSize(TQSize s)
MATRIX_DEBUG << "MatrixView::setViewSize() contentsWidth = " << getCanvasView()->contentsWidth() << endl;
}
-void MatrixView::repaintRulers()
+void MatrixView::tqrepaintRulers()
{
for (unsigned int i = 0; i != m_propertyViewRulers.size(); i++)
- m_propertyViewRulers[i].first->repaint();
+ m_propertyViewRulers[i].first->tqrepaint();
}
void MatrixView::updateView()
@@ -1156,7 +1156,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
i != s->getSegmentEvents().end(); ++i) {
if (oldSelection && oldSelection->getSegment() == s->getSegment()
- && oldSelection->contains(*i))
+ && oldSelection->tqcontains(*i))
continue;
foundNewEvent = true;
@@ -1196,8 +1196,8 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
getStaff(segment)->positionElements(std::min(startA, startB),
std::max(endA, endB));
} else {
- // mark refresh status and then request a repaint
- segment.getRefreshStatus
+ // mark refresh status and then request a tqrepaint
+ segment.getRefreshtqStatus
(m_segmentsRefreshStatusIds
[getStaff(segment)->getId()]).
push(std::min(startA, startB), std::max(endA, endB));
@@ -1213,14 +1213,14 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
getStaff(s->getSegment())->positionElements(startB, endB);
} else {
- // mark refresh status and then request a repaint
+ // mark refresh status and then request a tqrepaint
- oldSelection->getSegment().getRefreshStatus
+ oldSelection->getSegment().getRefreshtqStatus
(m_segmentsRefreshStatusIds
[getStaff(oldSelection->getSegment())->getId()]).
push(startA, endA);
- s->getSegment().getRefreshStatus
+ s->getSegment().getRefreshtqStatus
(m_segmentsRefreshStatusIds
[getStaff(s->getSegment())->getId()]).
push(startB, endB);
@@ -1254,11 +1254,11 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
if (s) {
stateChanged("have_selection", KXMLGUIClient::StateNoReverse);
- if (s->contains(Note::EventType)) {
+ if (s->tqcontains(Note::EventType)) {
stateChanged("have_notes_in_selection",
KXMLGUIClient::StateNoReverse);
}
- if (s->contains(Note::EventRestType)) {
+ if (s->tqcontains(Note::EventRestType)) {
stateChanged("have_rests_in_selection",
KXMLGUIClient::StateNoReverse);
}
@@ -1315,10 +1315,10 @@ void MatrixView::slotSelectSelected()
EditTool* selector = m_toolBox->getTool(MatrixSelector::ToolName);
connect(selector, TQT_SIGNAL(gotSelection()),
- this, TQT_SLOT(slotNewSelection()));
+ TQT_TQOBJECT(this), TQT_SLOT(slotNewSelection()));
connect(selector, TQT_SIGNAL(editTriggerSegment(int)),
- this, TQT_SIGNAL(editTriggerSegment(int)));
+ TQT_TQOBJECT(this), TQT_SIGNAL(editTriggerSegment(int)));
setTool(selector);
}
@@ -1398,7 +1398,7 @@ void MatrixView::slotMousePressed(timeT time, int pitch,
m_tool->handleMousePress(time, pitch, 0, e, el);
- if (e->button() != RightButton) {
+ if (e->button() != Qt::RightButton) {
getCanvasView()->startAutoScroll();
}
@@ -1474,13 +1474,13 @@ MatrixView::slotHoveredOverNoteChanged(int evPitch,
long ms = rt.msec();
TQString msg = i18n("Note: %1 (%2.%3s)")
- .arg(TQString("%1-%2-%3-%4")
- .arg(TQString("%1").arg(bar + 1).rightJustify(3, '0'))
- .arg(TQString("%1").arg(beat).rightJustify(2, '0'))
- .arg(TQString("%1").arg(fraction).rightJustify(2, '0'))
- .arg(TQString("%1").arg(remainder).rightJustify(2, '0')))
- .arg(rt.sec)
- .arg(TQString("%1").arg(ms).rightJustify(3, '0'));
+ .tqarg(TQString("%1-%2-%3-%4")
+ .tqarg(TQString("%1").tqarg(bar + 1).rightJustify(3, '0'))
+ .tqarg(TQString("%1").tqarg(beat).rightJustify(2, '0'))
+ .tqarg(TQString("%1").tqarg(fraction).rightJustify(2, '0'))
+ .tqarg(TQString("%1").tqarg(remainder).rightJustify(2, '0')))
+ .tqarg(rt.sec)
+ .tqarg(TQString("%1").tqarg(ms).rightJustify(3, '0'));
m_hoveredOverAbsoluteTime->setText(msg);
}
@@ -1488,8 +1488,8 @@ MatrixView::slotHoveredOverNoteChanged(int evPitch,
m_haveHoveredOverNote = false;
m_hoveredOverNoteName->setText(i18n("%1 (%2)")
- .arg(label.getQString())
- .arg(evPitch));
+ .tqarg(label.getTQString())
+ .tqarg(evPitch));
m_pitchRuler->drawHoverNote(evPitch);
}
@@ -1504,7 +1504,7 @@ MatrixView::slotHoveredOverKeyChanged(unsigned int y)
if (evPitch != m_previousEvPitch) {
MidiPitchLabel label(evPitch);
m_hoveredOverNoteName->setText(TQString("%1 (%2)").
- arg(label.getQString()).arg(evPitch));
+ tqarg(label.getTQString()).tqarg(evPitch));
m_previousEvPitch = evPitch;
}
}
@@ -1529,13 +1529,13 @@ MatrixView::slotHoveredOverAbsoluteTimeChanged(unsigned int time)
// to support Unicode
TQString message = i18n("Time: %1 (%2.%3s)")
- .arg(TQString("%1-%2-%3-%4")
- .arg(TQString("%1").arg(bar + 1).rightJustify(3, '0'))
- .arg(TQString("%1").arg(beat).rightJustify(2, '0'))
- .arg(TQString("%1").arg(fraction).rightJustify(2, '0'))
- .arg(TQString("%1").arg(remainder).rightJustify(2, '0')))
- .arg(rt.sec)
- .arg(TQString("%1").arg(ms).rightJustify(3, '0'));
+ .tqarg(TQString("%1-%2-%3-%4")
+ .tqarg(TQString("%1").tqarg(bar + 1).rightJustify(3, '0'))
+ .tqarg(TQString("%1").tqarg(beat).rightJustify(2, '0'))
+ .tqarg(TQString("%1").tqarg(fraction).rightJustify(2, '0'))
+ .tqarg(TQString("%1").tqarg(remainder).rightJustify(2, '0')))
+ .tqarg(rt.sec)
+ .tqarg(TQString("%1").tqarg(ms).rightJustify(3, '0'));
m_hoveredOverAbsoluteTime->setText(message);
}
@@ -1552,7 +1552,7 @@ MatrixView::slotSetPointerPosition(timeT time, bool scroll)
Composition &comp = getDocument()->getComposition();
int barNo = comp.getBarNumber(time);
- if (barNo >= m_hlayout.getLastVisibleBarOnStaff(*m_staffs[0])) {
+ if (barNo >= m_htqlayout.getLastVisibleBarOnStaff(*m_staffs[0])) {
Segment &seg = m_staffs[0]->getSegment();
@@ -1561,20 +1561,20 @@ MatrixView::slotSetPointerPosition(timeT time, bool scroll)
seg.getStartTime() +
((time - seg.getStartTime()) %
(seg.getEndMarkerTime() - seg.getStartTime()));
- m_staffs[0]->setPointerPosition(m_hlayout, time);
+ m_staffs[0]->setPointerPosition(m_htqlayout, time);
} else {
m_staffs[0]->hidePointer();
scroll = false;
}
- } else if (barNo < m_hlayout.getFirstVisibleBarOnStaff(*m_staffs[0])) {
+ } else if (barNo < m_htqlayout.getFirstVisibleBarOnStaff(*m_staffs[0])) {
m_staffs[0]->hidePointer();
scroll = false;
} else {
- m_staffs[0]->setPointerPosition(m_hlayout, time);
+ m_staffs[0]->setPointerPosition(m_htqlayout, time);
}
if (scroll && !getCanvasView()->isAutoScrolling())
- getCanvasView()->slotScrollHoriz(static_cast<int>(getXbyWorldMatrix(m_hlayout.getXForTime(time))));
+ getCanvasView()->slotScrollHoriz(static_cast<int>(getXbyWorldMatrix(m_htqlayout.getXForTime(time))));
updateView();
}
@@ -1585,11 +1585,11 @@ MatrixView::slotSetInsertCursorPosition(timeT time, bool scroll)
//!!! For now. Probably unlike slotSetPointerPosition this one
// should snap to the nearest event or grid line.
- m_staffs[0]->setInsertCursorPosition(m_hlayout, time);
+ m_staffs[0]->setInsertCursorPosition(m_htqlayout, time);
if (scroll && !getCanvasView()->isAutoScrolling()) {
getCanvasView()->slotScrollHoriz
- (static_cast<int>(getXbyWorldMatrix(m_hlayout.getXForTime(time))));
+ (static_cast<int>(getXbyWorldMatrix(m_htqlayout.getXForTime(time))));
}
updateView();
@@ -1810,7 +1810,7 @@ void MatrixView::slotVerticalScrollPianoKeyboard(int y)
void MatrixView::slotInsertNoteFromAction()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
TQString name = s->name();
Segment &segment = *getCurrentSegment();
@@ -1830,7 +1830,7 @@ void MatrixView::slotInsertNoteFromAction()
} catch (...) {
KMessageBox::sorry
- (this, i18n("Unknown note insert action %1").arg(name));
+ (this, i18n("Unknown note insert action %1").tqarg(name));
return ;
}
@@ -2017,7 +2017,7 @@ MatrixView::slotSetSnapFromIndex(int s)
void
MatrixView::slotSetSnapFromAction()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
TQString name = s->name();
if (name.left(5) == "snap_") {
@@ -2052,7 +2052,7 @@ MatrixView::slotSetSnap(timeT t)
}
for (unsigned int i = 0; i < m_staffs.size(); ++i)
- m_staffs[i]->sizeStaff(m_hlayout);
+ m_staffs[i]->sizeStaff(m_htqlayout);
m_segments[0]->setSnapGridSize(t);
@@ -2120,7 +2120,7 @@ MatrixView::initActionsToolbar()
TQLabel *sLabel = new TQLabel(i18n(" Grid: "), actionsToolbar, "kde toolbar widget");
sLabel->setIndent(10);
- TQPixmap noMap = NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap("menu-no-note"));
+ TQPixmap noMap = NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap("menu-no-note"));
m_snapGridCombo = new KComboBox(actionsToolbar);
@@ -2139,7 +2139,7 @@ MatrixView::initActionsToolbar()
} else {
timeT err = 0;
TQString label = NotationStrings::makeNoteMenuLabel(d, true, err);
- TQPixmap pixmap = NotePixmapFactory::toQPixmap
+ TQPixmap pixmap = NotePixmapFactory::toTQPixmap
(NotePixmapFactory::makeNoteMenuPixmap(d, err));
m_snapGridCombo->insertItem((err ? noMap : pixmap), label);
}
@@ -2150,7 +2150,7 @@ MatrixView::initActionsToolbar()
}
connect(m_snapGridCombo, TQT_SIGNAL(activated(int)),
- this, TQT_SLOT(slotSetSnapFromIndex(int)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotSetSnapFromIndex(int)));
// Velocity combo. Not a spin box, because the spin box is too
// slow to use unless we make it typeable into, and then it takes
@@ -2161,7 +2161,7 @@ MatrixView::initActionsToolbar()
m_velocityCombo = new KComboBox(actionsToolbar);
for (int i = 0; i <= 127; ++i) {
- m_velocityCombo->insertItem(TQString("%1").arg(i));
+ m_velocityCombo->insertItem(TQString("%1").tqarg(i));
}
m_velocityCombo->setCurrentItem(100); //!!! associate with segment
@@ -2177,14 +2177,14 @@ MatrixView::initActionsToolbar()
timeT time = m_quantizations[i];
timeT error = 0;
TQString label = NotationStrings::makeNoteMenuLabel(time, true, error);
- TQPixmap pmap = NotePixmapFactory::toQPixmap(NotePixmapFactory::makeNoteMenuPixmap(time, error));
+ TQPixmap pmap = NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeNoteMenuPixmap(time, error));
m_quantizeCombo->insertItem(error ? noMap : pmap, label);
}
m_quantizeCombo->insertItem(noMap, i18n("Off"));
connect(m_quantizeCombo, TQT_SIGNAL(activated(int)),
- this, TQT_SLOT(slotQuantizeSelection(int)));
+ TQT_TQOBJECT(this), TQT_SLOT(slotQuantizeSelection(int)));
}
void
@@ -2217,9 +2217,9 @@ MatrixView::initZoomToolbar()
}
m_hZoomSlider = new ZoomSlider<double>
- (zoomSizes, -1, TQSlider::Horizontal, zoomToolbar, "kde toolbar widget");
+ (zoomSizes, -1, Qt::Horizontal, zoomToolbar, "kde toolbar widget");
m_hZoomSlider->setTracking(true);
- m_hZoomSlider->setFocusPolicy(TQWidget::NoFocus);
+ m_hZoomSlider->setFocusPolicy(TQ_NoFocus);
m_zoomLabel = new TQLabel(zoomToolbar, "kde toolbar widget");
m_zoomLabel->setIndent(10);
@@ -2236,8 +2236,8 @@ MatrixView::slotChangeHorizontalZoom(int)
{
double zoomValue = m_hZoomSlider->getCurrentSize();
- // m_zoomLabel->setText(i18n("%1%").arg(zoomValue*100.0 * 2)); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
- m_zoomLabel->setText(i18n("%1%").arg(zoomValue*100.0));
+ // m_zoomLabel->setText(i18n("%1%").tqarg(zoomValue*100.0 * 2)); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
+ m_zoomLabel->setText(i18n("%1%").tqarg(zoomValue*100.0));
MATRIX_DEBUG << "MatrixView::slotChangeHorizontalZoom() : zoom factor = "
<< zoomValue << endl;
@@ -2245,9 +2245,9 @@ MatrixView::slotChangeHorizontalZoom(int)
m_referenceRuler->setHScaleFactor(zoomValue);
if (m_tempoRuler)
- m_tempoRuler->repaint();
+ m_tempoRuler->tqrepaint();
if (m_chordNameRuler)
- m_chordNameRuler->repaint();
+ m_chordNameRuler->tqrepaint();
// Set zoom matrix
//
@@ -2266,7 +2266,7 @@ MatrixView::slotChangeHorizontalZoom(int)
for (unsigned int i = 0; i < m_propertyViewRulers.size(); ++i) {
m_propertyViewRulers[i].first->setHScaleFactor(zoomValue);
- m_propertyViewRulers[i].first->repaint();
+ m_propertyViewRulers[i].first->tqrepaint();
}
if (m_topStandardRuler)
@@ -2314,8 +2314,8 @@ MatrixView::slotZoomOut()
void
MatrixView::scrollToTime(timeT t)
{
- double layoutCoord = m_hlayout.getXForTime(t);
- getCanvasView()->slotScrollHoriz(int(layoutCoord));
+ double tqlayoutCoord = m_htqlayout.getXForTime(t);
+ getCanvasView()->slotScrollHoriz(int(tqlayoutCoord));
}
int
@@ -2366,7 +2366,7 @@ MatrixView::addPropertyViewRuler(const PropertyName &property)
int height = 20;
- PropertyViewRuler *newRuler = new PropertyViewRuler(&m_hlayout,
+ PropertyViewRuler *newRuler = new PropertyViewRuler(&m_htqlayout,
m_segments[0],
property,
xorigin,
@@ -2409,7 +2409,7 @@ MatrixView::removePropertyViewRuler(unsigned int number)
RulerScale*
MatrixView::getHLayout()
{
- return &m_hlayout;
+ return &m_htqlayout;
}
Staff*
@@ -2429,14 +2429,14 @@ timeT
MatrixView::getInsertionTime()
{
MatrixStaff *staff = m_staffs[0];
- return staff->getInsertCursorTime(m_hlayout);
+ return staff->getInsertCursorTime(m_htqlayout);
}
void
MatrixView::slotStepBackward()
{
timeT time(getInsertionTime());
- slotSetInsertCursorPosition(SnapGrid(&m_hlayout).snapTime
+ slotSetInsertCursorPosition(SnapGrid(&m_htqlayout).snapTime
(time - 1,
SnapGrid::SnapLeft));
}
@@ -2445,7 +2445,7 @@ void
MatrixView::slotStepForward()
{
timeT time(getInsertionTime());
- slotSetInsertCursorPosition(SnapGrid(&m_hlayout).snapTime
+ slotSetInsertCursorPosition(SnapGrid(&m_htqlayout).snapTime
(time + 1,
SnapGrid::SnapRight));
}
@@ -2553,7 +2553,7 @@ MatrixView::readjustCanvasSize()
MatrixStaff &staff = *m_staffs[i];
- staff.sizeStaff(m_hlayout);
+ staff.sizeStaff(m_htqlayout);
// if (staff.getTotalWidth() + staff.getX() > maxWidth) {
// maxWidth = staff.getTotalWidth() + staff.getX() + 1;
@@ -2574,7 +2574,7 @@ MatrixView::readjustCanvasSize()
// now get the EditView to do the biz
readjustViewSize(TQSize(newWidth, maxHeight), true);
- repaintRulers();
+ tqrepaintRulers();
}
void MatrixView::slotVelocityUp()
@@ -2721,23 +2721,23 @@ MatrixView::updateViewCaption()
trackPosition = track->getPosition();
setCaption(i18n("%1 - Segment Track #%2 - %3")
- .arg(getDocument()->getTitle())
- .arg(trackPosition + 1)
- .arg(view));
+ .tqarg(getDocument()->getTitle())
+ .tqarg(trackPosition + 1)
+ .tqarg(view));
} else if (m_segments.size() == getDocument()->getComposition().getNbSegments()) {
setCaption(i18n("%1 - All Segments - %2")
- .arg(getDocument()->getTitle())
- .arg(view));
+ .tqarg(getDocument()->getTitle())
+ .tqarg(view));
} else {
setCaption(i18n("%1 - 1 Segment - %2",
"%1 - %n Segments - %2",
m_segments.size())
- .arg(getDocument()->getTitle())
- .arg(view));
+ .tqarg(getDocument()->getTitle())
+ .tqarg(view));
}
}
@@ -2745,10 +2745,10 @@ int MatrixView::computePostLayoutWidth()
{
Segment *segment = m_segments[0];
Composition *composition = segment->getComposition();
- int endX = int(m_hlayout.getXForTime
+ int endX = int(m_htqlayout.getXForTime
(composition->getBarEndForTime
(segment->getEndMarkerTime())));
- int startX = int(m_hlayout.getXForTime
+ int startX = int(m_htqlayout.getXForTime
(composition->getBarStartForTime
(segment->getStartTime())));
@@ -2921,14 +2921,14 @@ MatrixView::slotToggleStepByStep()
return ;
}
if (action->isChecked()) { // after toggling, that is
- emit stepByStepTargetRequested(this);
+ emit stepByStepTargetRequested(TQT_TQOBJECT(this));
} else {
emit stepByStepTargetRequested(0);
}
}
void
-MatrixView::slotUpdateInsertModeStatus()
+MatrixView::slotUpdateInsertModetqStatus()
{
TQString message;
if (isInChordMode()) {
@@ -2948,7 +2948,7 @@ MatrixView::slotStepByStepTargetRequested(TQObject *obj)
MATRIX_DEBUG << "WARNING: No toggle_step_by_step action" << endl;
return ;
}
- action->setChecked(obj == this);
+ action->setChecked(TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(this));
}
void
@@ -3026,35 +3026,35 @@ MatrixView::slotPercussionSetChanged(Instrument * newInstr)
TQObject::connect
(pitchRuler, TQT_SIGNAL(hoveredOverKeyChanged(unsigned int)),
- this, TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotHoveredOverKeyChanged(unsigned int)));
TQObject::connect
(pitchRuler, TQT_SIGNAL(keyPressed(unsigned int, bool)),
- this, TQT_SLOT (slotKeyPressed(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeyPressed(unsigned int, bool)));
TQObject::connect
(pitchRuler, TQT_SIGNAL(keySelected(unsigned int, bool)),
- this, TQT_SLOT (slotKeySelected(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeySelected(unsigned int, bool)));
TQObject::connect
(pitchRuler, TQT_SIGNAL(keyReleased(unsigned int, bool)),
- this, TQT_SLOT (slotKeyReleased(unsigned int, bool)));
+ TQT_TQOBJECT(this), TQT_SLOT (slotKeyReleased(unsigned int, bool)));
// Replace the old pitchruler widget
m_pitchRuler = pitchRuler;
m_pianoView->addChild(m_pitchRuler);
m_pitchRuler->show();
- m_pianoView->setFixedWidth(pitchRuler->sizeHint().width());
+ m_pianoView->setFixedWidth(pitchRuler->tqsizeHint().width());
// Update matrix canvas
readjustCanvasSize();
- bool layoutApplied = applyLayout();
- if (!layoutApplied)
- KMessageBox::sorry(0, i18n("Couldn't apply piano roll layout"));
+ bool tqlayoutApplied = applyLayout();
+ if (!tqlayoutApplied)
+ KMessageBox::sorry(0, i18n("Couldn't apply piano roll tqlayout"));
else {
MATRIX_DEBUG << "MatrixView : rendering elements\n";
m_staffs[0]->positionAllElements();
- m_staffs[0]->getSegment().getRefreshStatus
+ m_staffs[0]->getSegment().getRefreshtqStatus
(m_segmentsRefreshStatusIds[0]).setNeedsRefresh(false);
update();
}
diff --git a/src/gui/editors/matrix/PianoKeyboard.cpp b/src/gui/editors/matrix/PianoKeyboard.cpp
index 47f8413..e61cdc6 100644
--- a/src/gui/editors/matrix/PianoKeyboard.cpp
+++ b/src/gui/editors/matrix/PianoKeyboard.cpp
@@ -46,8 +46,8 @@ namespace Rosegarden
const unsigned int _smallWhiteKeyHeight = 14;
const unsigned int _whiteKeyHeight = 18;
-PianoKeyboard::PianoKeyboard(TQWidget *parent, int keys)
- : PitchRuler(parent),
+PianoKeyboard::PianoKeyboard(TQWidget *tqparent, int keys)
+ : PitchRuler(tqparent),
m_keySize(48, 18),
m_blackKeySize(24, 8),
m_nbKeys(keys),
@@ -65,13 +65,13 @@ PianoKeyboard::PianoKeyboard(TQWidget *parent, int keys)
setMouseTracking(true);
}
-TQSize PianoKeyboard::sizeHint() const
+TQSize PianoKeyboard::tqsizeHint() const
{
return TQSize(m_keySize.width(),
m_keySize.height() * m_nbKeys);
}
-TQSize PianoKeyboard::minimumSizeHint() const
+TQSize PianoKeyboard::tqminimumSizeHint() const
{
return m_keySize;
}
@@ -151,10 +151,10 @@ void PianoKeyboard::paintEvent(TQPaintEvent*)
MidiPitchLabel label(pitch);
paint.drawText(m_blackKeySize.width(), m_labelKeyPos[i],
- label.getQString());
+ label.getTQString());
}
- paint.setBrush(colorGroup().foreground());
+ paint.setBrush(tqcolorGroup().foreground());
for (unsigned int i = 0; i < m_blackKeyPos.size(); ++i)
paint.drawRect(0, m_blackKeyPos[i],
@@ -249,7 +249,7 @@ void PianoKeyboard::mouseMoveEvent(TQMouseEvent* e)
//
// RWB (20040220)
//
- MatrixView *matrixView = dynamic_cast<MatrixView*>(topLevelWidget());
+ MatrixView *matrixView = dynamic_cast<MatrixView*>(tqtopLevelWidget());
if (matrixView) {
MatrixStaff *staff = matrixView->getStaff(0);
@@ -272,11 +272,11 @@ void PianoKeyboard::mouseMoveEvent(TQMouseEvent* e)
void PianoKeyboard::mousePressEvent(TQMouseEvent *e)
{
- Qt::ButtonState bs = e->state();
+ TQt::ButtonState bs = e->state();
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
m_mouseDown = true;
- m_selecting = (bs & Qt::ShiftButton);
+ m_selecting = (bs & TQt::ShiftButton);
m_lastKeyPressed = e->y();
if (m_selecting)
@@ -288,7 +288,7 @@ void PianoKeyboard::mousePressEvent(TQMouseEvent *e)
void PianoKeyboard::mouseReleaseEvent(TQMouseEvent *e)
{
- if (e->button() == LeftButton) {
+ if (e->button() == Qt::LeftButton) {
m_mouseDown = false;
m_selecting = false;
emit keyReleased(e->y(), false);
diff --git a/src/gui/editors/matrix/PianoKeyboard.h b/src/gui/editors/matrix/PianoKeyboard.h
index 82c2be6..c8c09e8 100644
--- a/src/gui/editors/matrix/PianoKeyboard.h
+++ b/src/gui/editors/matrix/PianoKeyboard.h
@@ -45,11 +45,12 @@ namespace Rosegarden
class PianoKeyboard : public PitchRuler
{
Q_OBJECT
+ TQ_OBJECT
public:
- PianoKeyboard(TQWidget *parent, int keys = 88);
+ PianoKeyboard(TQWidget *tqparent, int keys = 88);
- virtual TQSize sizeHint() const;
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqsizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
/*
* We want to be able to call this from the matrix view
diff --git a/src/gui/editors/matrix/QCanvasMatrixDiamond.cpp b/src/gui/editors/matrix/QCanvasMatrixDiamond.cpp
index 128d3f9..d8d7b06 100644
--- a/src/gui/editors/matrix/QCanvasMatrixDiamond.cpp
+++ b/src/gui/editors/matrix/QCanvasMatrixDiamond.cpp
@@ -52,7 +52,7 @@ TQPointArray QCanvasMatrixDiamond::areaPoints() const
int pw = (pen().width() + 1) / 2;
if ( pw < 1 )
pw = 1;
- if ( pen() == NoPen )
+ if ( pen() == Qt::NoPen )
pw = 0;
pa[0] = TQPoint((int)x() - height() / 2 - pw, (int)y() - pw);
pa[1] = pa[0] + TQPoint(height() + pw * 2, 0);
@@ -68,7 +68,7 @@ void QCanvasMatrixDiamond::drawShape(TQPainter & p)
TQPointArray pa(4);
int q = height() / 2 + 2;
- TQPoint mapPos = p.worldMatrix().map(TQPoint(int(x()), int(y())));
+ TQPoint mapPos = p.tqworldMatrix().map(TQPoint(int(x()), int(y())));
pa[0] = TQPoint(mapPos.x(), mapPos.y() - 3);
pa[1] = TQPoint(mapPos.x() + q, mapPos.y() - 3 + q);
diff --git a/src/gui/editors/matrix/QCanvasMatrixDiamond.h b/src/gui/editors/matrix/QCanvasMatrixDiamond.h
index 547d7f1..8b736e7 100644
--- a/src/gui/editors/matrix/QCanvasMatrixDiamond.h
+++ b/src/gui/editors/matrix/QCanvasMatrixDiamond.h
@@ -23,8 +23,8 @@
COPYING included with this distribution for more information.
*/
-#ifndef _RG_QCANVASMATRIXDIAMOND_H_
-#define _RG_QCANVASMATRIXDIAMOND_H_
+#ifndef _RG_TQCANVASMATRIXDIAMOND_H_
+#define _RG_TQCANVASMATRIXDIAMOND_H_
#include "QCanvasMatrixRectangle.h"
#include <tqpointarray.h>
@@ -41,7 +41,7 @@ class MatrixElement;
/**
- * A TQCanvas diamond shape referencing a MatrixElement
+ * A TQCanvas diamond tqshape referencing a MatrixElement
*/
class QCanvasMatrixDiamond : public QCanvasMatrixRectangle
{
diff --git a/src/gui/editors/matrix/QCanvasMatrixRectangle.h b/src/gui/editors/matrix/QCanvasMatrixRectangle.h
index 6ef7ed8..12c209d 100644
--- a/src/gui/editors/matrix/QCanvasMatrixRectangle.h
+++ b/src/gui/editors/matrix/QCanvasMatrixRectangle.h
@@ -23,8 +23,8 @@
COPYING included with this distribution for more information.
*/
-#ifndef _RG_QCANVASMATRIXRECTANGLE_H_
-#define _RG_QCANVASMATRIXRECTANGLE_H_
+#ifndef _RG_TQCANVASMATRIXRECTANGLE_H_
+#define _RG_TQCANVASMATRIXRECTANGLE_H_
#include <tqcanvas.h>
@@ -38,7 +38,7 @@ class MatrixElement;
/**
* A TQCanvasRectangle referencing a MatrixElement
*/
-class QCanvasMatrixRectangle : public QCanvasRectangle
+class QCanvasMatrixRectangle : public TQCanvasRectangle
{
public:
QCanvasMatrixRectangle(MatrixElement&, TQCanvas*);
diff --git a/src/gui/editors/matrix/MatrixHLayout.h b/src/gui/editors/matrix/MatrixHLayout.h
index 76f1b31..291d618 100644
--- a/src/gui/editors/matrix/MatrixHLayout.h
+++ b/src/gui/editors/matrix/MatrixHLayout.h
@@ -62,7 +62,7 @@ public:
timeT = 0);
/**
* Returns the total length of all elements once layout is done.
* This is the x-coord of the end of the last element on the
* longest staff
*/
@@ -84,9 +84,9 @@ public:
virtual double getBarPosition(int barNo) const;
/**
* Precomputes layout data for a single staff, updating any
* internal data stores associated with that staff and updating
* any layout-related properties in the events on the staff's
* segment.
*/
virtual void scanStaff(Staff&,
@@ -94,10 +94,10 @@ public:
timeT = 0);
/**
* Computes any layout data that may depend on the results of
* scanning more than one staff. This may mean doing most of
* the layout (likely for horizontal layout) or nothing at all
* (likely for vertical layout).
*/
virtual void finishLayout(timeT = 0,
timeT = 0);
@@ -118,7 +118,7 @@ protected:
// pair of has-time-sig and time-sig
typedef std::pair<bool, TimeSignature> TimeSigData;
// pair of layout-x and time-signature if there is one
typedef std::pair<double, TimeSigData> BarData;
typedef FastVector<BarData> BarDataList;
BarDataList m_barData;
@@ -133,7 +133,7 @@ protected:
*/
class ZoomableMatrixHLayoutRulerScale : public RulerScale, public HZoomable {
public:
- ZoomableMatrixHLayoutRulerScale(MatrixHLayout& layout) : RulerScale(layout.getComposition()), m_referenceHLayout(layout) {};
+ ZoomableMatrixHLayoutRulerScale(MatrixHLayout& tqlayout) : RulerScale(tqlayout.getComposition()), m_referenceHLayout(tqlayout) {};
virtual double getBarPosition(int n) const { return m_referenceHLayout.getBarPosition(n) * getHScaleFactor(); }
virtual double getXForTime(timeT time) const { return m_referenceHLayout.getXForTime(time) * getHScaleFactor(); }
@@ -62,7 +62,7 @@ public:
timeT = 0);
/**
- * Returns the total length of all elements once layout is done.
+ * Returns the total length of all elements once tqlayout is done.
* This is the x-coord of the end of the last element on the
* longest staff
@@ -84,9 +84,9 @@ public:
virtual double getBarPosition(int barNo) const;
/**
- * Precomputes layout data for a single staff, updating any
+ * Precomputes tqlayout data for a single staff, updating any
* internal data stores associated with that staff and updating
@@ -84,9 +84,9 @@ public:
* internal data stores associated with that staff and updating
- * any layout-related properties in the events on the staff's
+ * any tqlayout-related properties in the events on the staff's
* segment.
*/
@@ -94,10 +94,10 @@ public:
timeT = 0);
/**
- * Computes any layout data that may depend on the results of
+ * Computes any tqlayout data that may depend on the results of
* scanning more than one staff. This may mean doing most of
@@ -94,10 +94,10 @@ public:
* scanning more than one staff. This may mean doing most of
- * the layout (likely for horizontal layout) or nothing at all
- * (likely for vertical layout).
+ * the tqlayout (likely for horizontal tqlayout) or nothing at all
+ * (likely for vertical tqlayout).
*/
virtual void finishLayout(timeT = 0,
@@ -118,7 +118,7 @@ protected:
// pair of has-time-sig and time-sig
typedef std::pair<bool, TimeSignature> TimeSigData;
- // pair of layout-x and time-signature if there is one
+ // pair of tqlayout-x and time-signature if there is one
typedef std::pair<double, TimeSigData> BarData;
typedef FastVector<BarData> BarDataList;
diff --git a/src/gui/editors/matrix/MatrixView.h b/src/gui/editors/matrix/MatrixView.h
index 0951c8c..d65b86a 100644
--- a/src/gui/editors/matrix/MatrixView.h
+++ b/src/gui/editors/matrix/MatrixView.h
@@ -82,13 +82,14 @@ class LevelInfo;
class MatrixView : public EditView
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixSelector;
public:
MatrixView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- TQWidget *parent, bool drumMode);
+ TQWidget *tqparent, bool drumMode);
virtual ~MatrixView();
@@ -189,7 +190,7 @@ public:
* Adjust an X coord by world matrix
*/
double getXbyWorldMatrix(double value)
- { return m_canvasView->worldMatrix().m11() * value; }
+ { return m_canvasView->tqworldMatrix().m11() * value; }
double getXbyInverseWorldMatrix(double value)
{ return m_canvasView->inverseWorldMatrix().m11() * value; }
@@ -200,7 +201,7 @@ public:
* Repaint the control rulers
*
*/
- void repaintRulers();
+ void tqrepaintRulers();
/*
* Readjust the canvas size
@@ -291,7 +292,7 @@ public slots:
void slotToggleStepByStep();
/// status stuff
- void slotUpdateInsertModeStatus();
+ void slotUpdateInsertModetqStatus();
/// transforms
void slotTransformsQuantize();
@@ -519,7 +520,7 @@ protected:
/**
* save general Options like all bar positions and status as well
- * as the geometry and the recent file list to the configuration
+ * as the tqgeometry and the recent file list to the configuration
* file
*/
virtual void slotSaveOptions();
@@ -593,13 +594,13 @@ protected:
std::vector<MatrixStaff*> m_staffs;
- MatrixHLayout m_hlayout;
- MatrixVLayout m_vlayout;
+ MatrixHLayout m_htqlayout;
+ MatrixVLayout m_vtqlayout;
SnapGrid *m_snapGrid;
timeT m_lastEndMarkerTime;
- // Status bar elements
+ // tqStatus bar elements
TQLabel* m_hoveredOverAbsoluteTime;
TQLabel* m_hoveredOverNoteName;
TQLabel *m_selectionCounter;
@@ -668,12 +669,13 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
// that Q_OBJECT can't be used in an inner class - gl
//
-// class NoteSender : public QObject
+// class NoteSender : public TQObject
// {
// Q_OBJECT
+// TQ_OBJECT
// public:
// NoteSender(int i, int p) : m_insid(i), m_pitch(p) { }
@@ -668,12 +669,13 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
-// that Q_OBJECT can't be used in an inner class - gl
+// that TQ_OBJECT can't be used in an inner class - gl
//